@@ -19,7 +19,7 @@ use strict;
 use vars qw($VERSION $warnString);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.22';
+$VERSION = '1.24';
 
 sub WarnProc($) { $warnString = $_[0]; }
 
@@ -43,6 +43,14 @@ my %iWorkFile = (
     'Index/Tables/DataList.iwa' => 'NUMBERS',
 );
 
+my %iWorkType = (
+    NUMBERS => 'NUMBERS',
+    PAGES   => 'PAGES',
+    KEY     => 'KEY',
+    KTH     => 'KTH',
+    NMBTEMPLATE => 'NMBTEMPLATE',
+);
+
 # ZIP metadata blocks
 %Image::ExifTool::ZIP::Main = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
@@ -491,8 +499,9 @@ sub ProcessZIP($$)
                     ($buff, $status) = $zip->contents($meta);
                     unless ($status) {
                         my %dirInfo = (
-                            DataPt => \$buff,
-                            DirLen => length $buff,
+                            DirName => 'XML',
+                            DataPt  => \$buff,
+                            DirLen  => length $buff,
                             DataLen => length $buff,
                         );
                         # (avoid structure warnings when copying from XML)
@@ -586,7 +595,8 @@ sub ProcessZIP($$)
                     $et->FoundTag($extract{$file} => $buff);
                 }
             } elsif ($file eq 'Index/Document.iwa' and not $iWorkType) {
-                $iWorkType = 'PAGES';
+                my $type = $iWorkType{$$et{FILE_EXT} || ''};
+                $iWorkType = $type || 'PAGES';
             } elsif ($iWorkFile{$file}) {
                 $iWorkType = $iWorkFile{$file};
             }
@@ -675,7 +685,7 @@ Electronic Publication (EPUB), and Sketch design files (SKETCH).
 
 =head1 AUTHOR
 
-Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
